@@ -35,11 +35,13 @@ class SelectivityComponent(BaseScoreComponent):
         try:
             activity_model = self._load_scikit_model(parameters)
         except Exception as e:
-            raise Exception(f"The loaded file {parameters.model_path} isn't a valid scikit-learn model: {e}.")
+            model_path = self.parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+            raise Exception(f"The loaded file `{model_path}` isn't a valid scikit-learn model: {e}.")
         return activity_model
 
     def _load_scikit_model(self, parameters: ComponentParameters) -> BaseModelContainer:
-        with open(parameters.model_path, "rb") as f:
+        model_path = parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+        with open(model_path, "rb") as f:
             scikit_model = pickle.load(f)
 
             models_are_identical = self._activity_params.specific_parameters[
@@ -84,10 +86,9 @@ class SelectivityComponent(BaseScoreComponent):
     def _prepare_activity_parameters(self, parameters: ComponentParameters) -> ComponentParameters:
         model_path = parameters.specific_parameters["activity_model_path"]
         specific_parameters = parameters.specific_parameters["activity_specific_parameters"]
+        specific_parameters['model_path'] = model_path
         activity_params = ComponentParameters(name=self.parameters.name,
                                               weight=self.parameters.weight,
-                                              smiles=self.parameters.smiles,
-                                              model_path=model_path,
                                               component_type=self.parameters.component_type,
                                               specific_parameters=specific_parameters
                                               )
@@ -96,10 +97,9 @@ class SelectivityComponent(BaseScoreComponent):
     def _prepare_offtarget_parameters(self, parameters: ComponentParameters) -> ComponentParameters:
         model_path = parameters.specific_parameters["offtarget_model_path"]
         specific_parameters = parameters.specific_parameters["offtarget_specific_parameters"]
+        specific_parameters['model_path'] = model_path
         offtarget_params = ComponentParameters(name=self.parameters.name,
                                                weight=self.parameters.weight,
-                                               smiles=self.parameters.smiles,
-                                               model_path=model_path,
                                                component_type=self.parameters.component_type,
                                                specific_parameters=specific_parameters
                                                )
